@@ -76,11 +76,16 @@ class JsonConfigSettingsSource(PydanticBaseSettingsSource):
         config_path = (
             self.settings_cls.model_fields["config_path"].default
             if self.settings_cls.model_fields.get("config_path")
-            else "config.json"
+            else "logqs-config.json"
         )
         if not os.path.exists(config_path):
             return None, field_name, False
         file_content_json = json.loads(Path(config_path).read_text(encoding))
+        field_value = file_content_json.get(field_name)
+
+        # config_key is name of app (e.g., "dsm")
+        # the config can be nested under the app name
+        # if present, we override the field_value if found
         config_key = (
             self.settings_cls.model_fields["config_key"].default
             if self.settings_cls.model_fields.get("config_key")
@@ -88,9 +93,8 @@ class JsonConfigSettingsSource(PydanticBaseSettingsSource):
         )
         if config_key:
             file_content_json = file_content_json.get(config_key)
-        if not isinstance(file_content_json, dict):
-            return None, field_name, False
-        field_value = file_content_json.get(field_name)
+            if isinstance(file_content_json, dict):
+                field_value = file_content_json.get(field_name, field_value)
         return field_value, field_name, False
 
     def prepare_field_value(
