@@ -140,3 +140,10 @@ class LogIntegrityException(Exception):
             else "The request couldn't be processed due to a log integrity error."
         )
         super().__init__(self.message)
+
+
+# Process Exceptions
+
+
+class AsyncIngestionError(Exception):
+    pass
