@@ -2,8 +2,8 @@ import json
 from typing import Type, Any, Union
 from logging import Logger
 
-from lqs.common.config import CommonConfig
 from lqs.common.utils import get_logger, ContextLoggerAdapter
+from lqs.common.config import CommonConfig
 from lqs.interface import core
 
 
@@ -22,25 +22,16 @@ class Facade:
         else:
             self.config: config_class = config
         log_level = self.config.log_level or "INFO"
+
+        self.correlation_id = getattr(self.config, "session_id", None)
         self.logger = get_logger(
             self.__class__.__name__,
             level=log_level,
             log_to_file=self.config.log_to_file,
             json_logging=self.config.log_as_json,
+            correlation_id=self.correlation_id,
         )
 
-    def debug(self, msg: str):
-        self.logger.debug(msg)
-
-    def info(self, msg: str):
-        self.logger.info(msg)
-
-    def warn(self, msg: str):
-        self.logger.warning(msg)
-
-    def error(self, msg: str):
-        self.logger.error(msg)
-
     def json(self, req):
         """
         Convert a JSON request to a dictionary.
