@@ -13,6 +13,7 @@ from typing import (
 from datetime import datetime
 from uuid import UUID
 from enum import Enum
+from concurrent.futures import ThreadPoolExecutor
 
 from pydantic import (
     BaseModel,
@@ -21,18 +22,46 @@ from pydantic import (
     WithJsonSchema,
     SerializerFunctionWrapHandler,
     WrapSerializer,
+    SerializationInfo,
 )
 
 from fastapi import Path
+import cattrs.preconf.json
+
+converter = cattrs.preconf.json.make_converter()
+converter.register_unstructure_hook(
+    cls=int, func=lambda x: str(x) if x > 2**53 else x
+)
 
 optional_field = Field(default=None, json_schema_extra=lambda x: x.pop("default"))
+optional_deprecated_field = Field(
+    default=None, deprecated=True, json_schema_extra=lambda x: x.pop("default")
+)
 
 
-def big_int_wrap(v: Any, nxt: SerializerFunctionWrapHandler) -> Union[str, int]:
-    # add custom logic once this feature-request is implemented https://github.com/pydantic/pydantic/issues/7143
+def special_dict_wrap(
+    v: Any, nxt: SerializerFunctionWrapHandler, info: SerializationInfo
+):
+    if info.context and info.context.get("stringify_bigints", False):
+        return converter.unstructure(v)
     return nxt(v)
 
 
+def big_int_wrap(
+    v: Any, nxt: SerializerFunctionWrapHandler, info: SerializationInfo
+) -> Union[str, int]:
+    if info.context and info.context.get("stringify_bigints", False):
+        return str(v)
+    return nxt(v)
+
+
+SpecialDict = Annotated[
+    dict,
+    dict,
+    WrapSerializer(special_dict_wrap, when_used="json"),
+]
+
+
 Int64 = Annotated[
     int,
     int,
@@ -62,7 +91,7 @@ T = TypeVar("T", bound="ResourceModel")
 
 
 class ResourceModel(BaseModel, Generic[T]):
-    # app: "RESTClient | Core | None" = None # TODO: prepend an underscore so Pydantic ignores this
+    _app: Any = None
     model_config = ConfigDict(from_attributes=True)
 
     @classmethod
@@ -94,7 +123,18 @@ class ResourceModel(BaseModel, Generic[T]):
                 continue
 
             field_type = field_info.annotation
-            if str(field_type).startswith("typing."):
+            if hasattr(field_type, "__args__"):
+                raw_sub_type_name = str(field_type.__args__[0])
+                if "typing.Annotated[int" in raw_sub_type_name:
+                    sub_type_name = "int"
+                else:
+                    sub_type_name = raw_sub_type_name
+                if str(field_type).startswith("typing."):
+                    type_name = str(field_type)[7:]
+                else:
+                    type_name = field_type.__name__
+                type_name = type_name.replace(raw_sub_type_name, sub_type_name)
+            elif str(field_type).startswith("typing."):
                 type_name = str(field_type)[7:]
             else:
                 type_name = field_type.__name__
@@ -124,7 +164,7 @@ class ResourceModel(BaseModel, Generic[T]):
 
     @classmethod
     def set_app(cls, app):
-        cls.app = app
+        cls._app = app
 
     @classmethod
     def fetch(cls: Type[T], *args, **kwargs) -> T:
@@ -133,9 +173,9 @@ class ResourceModel(BaseModel, Generic[T]):
         parent_id = None
         if len(args) > 0:
             try:
-                if type(args[0]) == UUID:
+                if type(args[0]) is UUID:
                     id = args[0]
-                elif type(args[0]) == int:
+                elif type(args[0]) is int:
                     id = int(args[0])
                 else:
                     id = UUID(args[0])
@@ -143,7 +183,7 @@ class ResourceModel(BaseModel, Generic[T]):
                 friendly_id = args[0]
             if len(args) > 1:
                 try:
-                    if type(args[1]) == UUID:
+                    if type(args[1]) is UUID:
                         parent_id = args[1]
                     else:
                         parent_id = UUID(args[1])
@@ -157,7 +197,7 @@ class ResourceModel(BaseModel, Generic[T]):
 
         if id is not None:
             fetch_method = getattr(
-                cls.app.fetch, convert_camel_to_snake_case(cls.__name__)
+                cls._app.fetch, convert_camel_to_snake_case(cls.__name__)
             )
             if parent_id is not None:
                 return fetch_method(id, parent_id, **kwargs).data
@@ -165,7 +205,7 @@ class ResourceModel(BaseModel, Generic[T]):
                 return fetch_method(id, **kwargs).data
         else:
             list_method = getattr(
-                cls.app.list, convert_camel_to_snake_case(cls.__name__)
+                cls._app.list, convert_camel_to_snake_case(cls.__name__)
             )
 
             list_args = {
@@ -188,7 +228,9 @@ class ResourceModel(BaseModel, Generic[T]):
                 raise ValueError(f"No {cls.__name__} found.")
             elif list_res.count > 1:
                 try:
-                    cls.app.warn(f"Multiple {cls.__name__}s ({list_res.count}) found.")
+                    cls._app.logger.warning(
+                        f"Multiple {cls.__name__}s ({list_res.count}) found."
+                    )
                 except AttributeError:
                     pass
             return list_res.data[0]
@@ -202,12 +244,28 @@ class ResourceModel(BaseModel, Generic[T]):
 
     @classmethod
     def list(cls: Type[T], **kwargs) -> List[T]:
-        list_method = getattr(cls.app.list, convert_camel_to_snake_case(cls.__name__))
+        list_method = getattr(cls._app.list, convert_camel_to_snake_case(cls.__name__))
         return list_method(**kwargs).data
 
+    @classmethod
+    def list_all(cls: Type[T], **kwargs) -> List[T]:
+        list_method = getattr(cls._app.list, convert_camel_to_snake_case(cls.__name__))
+        offset = kwargs.pop("offset", 0)
+        limit = kwargs.pop("limit", 100)
+        total_count = float("inf")
+        resources = []
+
+        while len(resources) < total_count:
+            res = list_method(**kwargs, offset=offset, limit=limit)
+            total_count = res.count
+            resources.extend(res.data)
+            offset += limit
+
+        return resources
+
     @classmethod
     def iterate_efficiently(cls: Type[T], **kwargs) -> Iterator[T]:
-        MAX_LIMIT = 1_000
+        MAX_LIMIT = 100
         order = kwargs.get("order", "created_at")
         assert order == "created_at"
         sort = kwargs.pop("sort", "desc")
@@ -237,7 +295,7 @@ class ResourceModel(BaseModel, Generic[T]):
 
     @classmethod
     def iterate(cls: Type[T], **kwargs) -> Iterator[T]:
-        MAX_LIMIT = 1_000
+        MAX_LIMIT = 100
         limit = kwargs.pop("limit", float("inf"))
         if not limit or limit > MAX_LIMIT:
             _limit = MAX_LIMIT
@@ -257,14 +315,14 @@ class ResourceModel(BaseModel, Generic[T]):
     @classmethod
     def create(cls: Type[T], **kwargs) -> T:
         create_method = getattr(
-            cls.app.create, convert_camel_to_snake_case(cls.__name__)
+            cls._app.create, convert_camel_to_snake_case(cls.__name__)
         )
         return create_method(**kwargs).data
 
     def update(self, **kwargs) -> T:
         # get the class name and convert it to snake case
         class_name = convert_camel_to_snake_case(self.__class__.__name__)
-        update_method = getattr(self.app.update, class_name)
+        update_method = getattr(self._app.update, class_name)
         updated_resource = update_method(self.id, data=kwargs).data
         for field, value in updated_resource.dict().items():
             # check that the field is a pydantic field
@@ -276,7 +334,7 @@ class ResourceModel(BaseModel, Generic[T]):
     @classmethod
     def delete(cls, **kwargs) -> None:
         delete_method = getattr(
-            cls.app.delete, convert_camel_to_snake_case(cls.__name__)
+            cls._app.delete, convert_camel_to_snake_case(cls.__name__)
         )
         return delete_method(**kwargs)
 
@@ -294,6 +352,62 @@ class ResourceModel(BaseModel, Generic[T]):
                 setattr(self, field, value)
         return self
 
+    def _list_all_subresources(self, list_method, threaded=True, **kwargs):
+        if threaded:
+            return self._list_all_subresources_threaded(list_method, **kwargs)
+        else:
+            return self._list_all_subresources_single(list_method, **kwargs)
+
+    def _list_all_subresources_single(self, list_method, **kwargs):
+        subresources = []
+        total_limit = kwargs.pop("limit", None)
+        limit = 100 if total_limit is None else min(100, total_limit)
+        offset = 0
+        kwargs["limit"] = limit
+        kwargs["offset"] = offset
+        while True:
+            res = list_method(**kwargs)
+            subresources.extend(res.data)
+            if len(res.data) < limit:
+                break
+            if total_limit is not None:
+                total_limit -= limit
+                if total_limit <= 0:
+                    break
+            offset += limit
+            kwargs["offset"] = offset
+        return subresources
+
+    def _list_all_subresources_threaded(self, list_method, **kwargs):
+        count_kwargs = kwargs.copy()
+        count_kwargs["include_count"] = True
+        count_kwargs["limit"] = 0
+        count_kwargs["offset"] = 0
+        count = list_method(**count_kwargs).count
+        if count == 0:
+            return []
+
+        subresources = []
+        total_limit = kwargs.pop("limit", None)
+        limit = 100 if total_limit is None else min(100, total_limit)
+        offset = 0
+        kwargs["limit"] = limit
+        kwargs["offset"] = offset
+        with ThreadPoolExecutor() as executor:
+            futures = []
+            while offset < count:
+                futures.append(executor.submit(list_method, **kwargs))
+                offset += limit
+                kwargs["offset"] = offset
+                if total_limit is not None:
+                    total_limit -= limit
+                    if total_limit <= 0:
+                        break
+            for future in futures:
+                res = future.result()
+                subresources.extend(res.data)
+        return subresources
+
 
 class CommonModel(ResourceModel[T]):
     id: UUID = Field(..., description="The ID of the resource.")
@@ -319,6 +433,8 @@ class CommonModel(ResourceModel[T]):
 
 
 class TimeSeriesModel(ResourceModel[T]):
+    _repr_fields = ("timestamp",)
+
     timestamp: Int64 = Field(..., description="The timestamp of the resource.")
 
     created_at: datetime = Field(
