@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import Optional
 from uuid import UUID
 
 from pydantic import BaseModel
@@ -9,13 +9,17 @@ from lqs.interface.base.models.__common__ import (
     PaginationModel,
     optional_field,
 )
+from lqs.interface.base import models
 
 
 class APIKey(CommonModel["APIKey"]):
     name: str
     user_id: UUID
     disabled: bool
-    secret: Optional[str] = optional_field  # TODO: figure out what to do here
+    secret: Optional[str]
+
+    def fetch_user(self) -> "models.User":
+        return self._app.fetch.user(self.user_id).data
 
 
 class APIKeyDataResponse(DataResponseModel[APIKey]):
