@@ -1,7 +1,7 @@
 from typing import List, Optional
 from enum import Enum
 
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict
 
 from lqs.interface.base.models.__common__ import (
     CommonModel,
@@ -9,6 +9,7 @@ from lqs.interface.base.models.__common__ import (
     PaginationModel,
     optional_field,
 )
+from lqs.interface.base import models
 
 
 class StatementEffect(str, Enum):
@@ -32,14 +33,18 @@ class Statement(BaseModel):
     effect: StatementEffect
     action: List[StatementAction] = []
     resource: List[str] = []
-    filter: dict = {}
+    filter: Optional[dict] = {}
+
+    model_config = ConfigDict(
+        json_schema_extra={"required": ["effect", "action", "resource", "filter"]}
+    )
 
 
 class Policy(BaseModel):
     statement: List[Statement]
 
 
-class Role(CommonModel["Role"]):
+class Role(CommonModel):
     name: str
     policy: Policy
     note: Optional[str]
@@ -48,6 +53,14 @@ class Role(CommonModel["Role"]):
     default: bool
     managed: bool
 
+    def list_users(self, threaded=False, **kwargs) -> list["models.User"]:
+        return self._list_all_subresources(
+            list_method=self._app.list.user,
+            threaded=threaded,
+            role_id=self.id,
+            **kwargs,
+        )
+
 
 class RoleDataResponse(DataResponseModel[Role]):
     pass
@@ -59,7 +72,7 @@ class RoleListResponse(PaginationModel[Role]):
 
 class RoleCreateRequest(BaseModel):
     name: str
-    policy: dict
+    policy: Policy
 
     note: Optional[str] = None
     disabled: bool = False
@@ -69,7 +82,7 @@ class RoleCreateRequest(BaseModel):
 
 class RoleUpdateRequest(BaseModel):
     name: str = optional_field
-    policy: dict = optional_field
+    policy: Policy = optional_field
     note: Optional[str] = optional_field
     disabled: bool = optional_field
     default: bool = optional_field
