@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import Optional
 from uuid import UUID
 
 from pydantic import BaseModel
@@ -9,9 +9,10 @@ from lqs.interface.base.models.__common__ import (
     PaginationModel,
     optional_field,
 )
+from lqs.interface.base import models
 
 
-class User(CommonModel["User"]):
+class User(CommonModel):
     _repr_fields = ("id", "username")
 
     username: str
@@ -19,7 +20,15 @@ class User(CommonModel["User"]):
     admin: bool
     disabled: bool
     managed: bool
-    external_id: Optional[str] = None
+    external_id: Optional[str]
+
+    def fetch_role(self) -> Optional["models.Role"]:
+        if self.role_id is None:
+            return None
+        return self._app.fetch.role(self.role_id).data
+
+    def list_api_keys(self) -> "models.APIKeyListResponse":
+        return self._app.fetch.api_keys(user_id=self.id)
 
 
 class UserDataResponse(BaseModel):
@@ -27,7 +36,7 @@ class UserDataResponse(BaseModel):
 
 
 class MeDataResponse(DataResponseModel[User]):
-    pass
+    data: Optional[User]
 
 
 class UserListResponse(PaginationModel[User]):
