@@ -8,6 +8,40 @@ from lqs.interface.core.models import ProcessState
 
 
 class CreateInterface(BaseCreateInterface):
+    @abstractmethod
+    def _callback(self, **kwargs) -> models.CallbackDataResponse:
+        pass
+
+    def callback(
+        self,
+        name: str,
+        note: Optional[str] = None,
+        context: Optional[dict] = None,
+        managed: Optional[bool] = False,
+        default: Optional[bool] = False,
+        disabled: Optional[bool] = False,
+        uri: Optional[str] = None,
+        secret: Optional[str] = None,
+        parameter_schema: Optional[dict] = None,
+    ):
+        return self._callback(
+            name=name,
+            note=note,
+            context=context,
+            managed=managed,
+            default=default,
+            disabled=disabled,
+            uri=uri,
+            secret=secret,
+            parameter_schema=parameter_schema,
+        )
+
+    def _callback_by_model(
+        self,
+        data: models.CallbackCreateRequest,
+    ):
+        return self.callback(**data.model_dump())
+
     @abstractmethod
     def _digestion(self, **kwargs) -> models.DigestionDataResponse:
         pass
@@ -74,6 +108,7 @@ class CreateInterface(BaseCreateInterface):
         self,
         digestion_id: UUID,
         sequence: int,
+        context: Optional[dict] = None,
         locked: Optional[bool] = False,
         workflow_id: Optional[UUID] = None,
         workflow_context: Optional[dict] = None,
@@ -104,6 +139,7 @@ class CreateInterface(BaseCreateInterface):
         return self._digestion_part(
             digestion_id=digestion_id,
             sequence=sequence,
+            context=context,
             locked=locked,
             workflow_id=workflow_id,
             workflow_context=workflow_context,
@@ -114,9 +150,16 @@ class CreateInterface(BaseCreateInterface):
 
     def _digestion_part_by_model(
         self,
-        digestion_id: UUID,
         data: models.DigestionPartCreateRequest,
         lock_token: Optional[str] = None,
+    ):
+        return self.digestion_part(**data.model_dump(), lock_token=lock_token)
+
+    def _digestion_part_for_digestion_by_model(
+        self,
+        digestion_id: UUID,
+        data: models.DigestionPartForDigestionCreateRequest,
+        lock_token: Optional[str] = None,
     ):
         return self.digestion_part(
             digestion_id=digestion_id, **data.model_dump(), lock_token=lock_token
@@ -170,9 +213,16 @@ class CreateInterface(BaseCreateInterface):
 
     def _digestion_topic_by_model(
         self,
-        digestion_id: UUID,
         data: models.DigestionTopicCreateRequest,
         lock_token: Optional[str] = None,
+    ):
+        return self.digestion_topic(**data.model_dump(), lock_token=lock_token)
+
+    def _digestion_topic_for_digestion_by_model(
+        self,
+        digestion_id: UUID,
+        data: models.DigestionTopicForDigestionCreateRequest,
+        lock_token: Optional[str] = None,
     ):
         return self.digestion_topic(
             digestion_id=digestion_id, **data.model_dump(), lock_token=lock_token
@@ -273,7 +323,12 @@ class CreateInterface(BaseCreateInterface):
             secret=secret,
         )
 
-    def _hook_by_model(self, workflow_id: UUID, data: models.HookCreateRequest):
+    def _hook_by_model(self, data: models.HookCreateRequest):
+        return self.hook(**data.model_dump())
+
+    def _hook_for_workflow_by_model(
+        self, workflow_id: UUID, data: models.HookForWorkflowCreateRequest
+    ):
         return self.hook(workflow_id=workflow_id, **data.model_dump())
 
     @abstractmethod
@@ -350,6 +405,7 @@ class CreateInterface(BaseCreateInterface):
         ingestion_id: UUID,
         sequence: int,
         source: Optional[str] = None,
+        context: Optional[dict] = None,
         locked: Optional[bool] = False,
         workflow_id: Optional[UUID] = None,
         workflow_context: Optional[dict] = None,
@@ -383,6 +439,7 @@ class CreateInterface(BaseCreateInterface):
             ingestion_id=ingestion_id,
             sequence=sequence,
             source=source,
+            context=context,
             locked=locked,
             workflow_id=workflow_id,
             workflow_context=workflow_context,
@@ -393,9 +450,16 @@ class CreateInterface(BaseCreateInterface):
 
     def _ingestion_part_by_model(
         self,
-        ingestion_id: UUID,
         data: models.IngestionPartCreateRequest,
         lock_token: Optional[str] = None,
+    ):
+        return self.ingestion_part(**data.model_dump(), lock_token=lock_token)
+
+    def _ingestion_part_for_ingestion_by_model(
+        self,
+        ingestion_id: UUID,
+        data: models.IngestionPartForIngestionCreateRequest,
+        lock_token: Optional[str] = None,
     ):
         return self.ingestion_part(
             ingestion_id=ingestion_id, **data.model_dump(), lock_token=lock_token
@@ -405,7 +469,9 @@ class CreateInterface(BaseCreateInterface):
     def _label(self, **kwargs) -> models.LabelDataResponse:
         pass
 
-    def label(self, value: str, note: Optional[str] = None):
+    def label(
+        self, value: str, note: Optional[str] = None, category: Optional[str] = None
+    ):
         """
         Create a label.
 
@@ -419,6 +485,7 @@ class CreateInterface(BaseCreateInterface):
         return self._label(
             value=value,
             note=note,
+            category=category,
         )
 
     def _label_by_model(self, data: models.LabelCreateRequest):
@@ -433,6 +500,7 @@ class CreateInterface(BaseCreateInterface):
         group_id: UUID,
         name: str,
         note: Optional[str] = None,
+        base_timestamp: Optional[int] = None,
         context: Optional[dict] = None,
         locked: Optional[bool] = False,
         default_workflow_id: Optional[UUID] = None,
@@ -447,6 +515,8 @@ class CreateInterface(BaseCreateInterface):
         :type name: str
         :param note: A note about the log. Defaults to None.
         :type note: str, optional
+        :param base_timestamp: The base timestamp of the log. Defaults to None.
+        :type base_timestamp: int, optional
         :param context: The context to use for the log. Defaults to None.
         :type context: dict, optional
         :param locked: Whether the log is locked. Defaults to False.
@@ -460,6 +530,7 @@ class CreateInterface(BaseCreateInterface):
             group_id=group_id,
             name=name,
             note=note,
+            base_timestamp=base_timestamp,
             context=context,
             locked=locked,
             default_workflow_id=default_workflow_id,
@@ -631,6 +702,7 @@ class CreateInterface(BaseCreateInterface):
 
     def object_store(
         self,
+        name: str,
         bucket_name: str,
         access_key_id: Optional[str] = None,
         secret_access_key: Optional[str] = None,
@@ -639,10 +711,16 @@ class CreateInterface(BaseCreateInterface):
         note: Optional[str] = None,
         context: Optional[dict] = None,
         disabled: Optional[bool] = False,
+        default: Optional[bool] = False,
+        read_only: Optional[bool] = False,
+        managed: Optional[bool] = False,
+        key_prefix: Optional[str] = None,
     ):
         """
         Create an object store.
 
+        :param name: The name of the object store. Must be unique within the DataStore.
+        :type name: str
         :param bucket_name: The name of the bucket.
         :type bucket_name: str
         :param access_key_id: The access key ID of the object store. Defaults to None.
@@ -663,6 +741,7 @@ class CreateInterface(BaseCreateInterface):
         :rtype: ObjectStoreDataResponse
         """
         return self._object_store(
+            name=name,
             bucket_name=bucket_name,
             access_key_id=access_key_id,
             secret_access_key=secret_access_key,
@@ -671,6 +750,10 @@ class CreateInterface(BaseCreateInterface):
             note=note,
             context=context,
             disabled=disabled,
+            default=default,
+            read_only=read_only,
+            managed=managed,
+            key_prefix=key_prefix,
         )
 
     def _object_store_by_model(self, data: models.ObjectStoreCreateRequest):
@@ -716,7 +799,12 @@ class CreateInterface(BaseCreateInterface):
             parameters=parameters,
         )
 
-    def _query_by_model(self, log_id: UUID, data: models.QueryCreateRequest):
+    def _query_by_model(self, data: models.QueryCreateRequest):
+        return self.query(**data.model_dump())
+
+    def _query_for_log_by_model(
+        self, log_id: UUID, data: models.QueryForLogCreateRequest
+    ):
         return self.query(log_id=log_id, **data.model_dump())
 
     @abstractmethod
@@ -847,9 +935,16 @@ class CreateInterface(BaseCreateInterface):
 
     def _tag_by_model(
         self,
-        log_id: UUID,
         data: models.TagCreateRequest,
         lock_token: Optional[str] = None,
+    ):
+        return self.tag(**data.model_dump(), lock_token=lock_token)
+
+    def _tag_for_log_by_model(
+        self,
+        log_id: UUID,
+        data: models.TagForLogCreateRequest,
+        lock_token: Optional[str] = None,
     ):
         return self.tag(log_id=log_id, **data.model_dump(), lock_token=lock_token)
 
@@ -862,6 +957,7 @@ class CreateInterface(BaseCreateInterface):
         log_id: UUID,
         name: str,
         note: Optional[str] = None,
+        base_timestamp: Optional[int] = None,
         context: Optional[dict] = None,
         associated_topic_id: Optional[UUID] = None,
         locked: Optional[bool] = False,
@@ -881,6 +977,8 @@ class CreateInterface(BaseCreateInterface):
         :type name: str
         :param note: A note about the topic. Defaults to None.
         :type note: str, optional
+        :param base_timestamp: The base timestamp of the topic. Defaults to None.
+        :type base_timestamp: int, optional
         :param context: The context to use for the topic. Defaults to None.
         :type context: dict, optional
         :param associated_topic_id: The ID of the associated topic. Defaults to None.
@@ -904,6 +1002,7 @@ class CreateInterface(BaseCreateInterface):
             log_id=log_id,
             name=name,
             note=note,
+            base_timestamp=base_timestamp,
             context=context,
             associated_topic_id=associated_topic_id,
             locked=locked,
@@ -927,6 +1026,7 @@ class CreateInterface(BaseCreateInterface):
     def workflow(
         self,
         name: str,
+        process_type: models.ProcessType = models.ProcessType.digestion,
         note: Optional[str] = None,
         context: Optional[dict] = None,
         default: Optional[bool] = False,
@@ -956,6 +1056,7 @@ class CreateInterface(BaseCreateInterface):
         """
         return self._workflow(
             name=name,
+            process_type=process_type,
             note=note,
             context=context,
             default=default,
