@@ -7,6 +7,15 @@ import lqs.interface.core.models as models
 
 
 class FetchInterface(BaseFetchInterface):
+    @abstractmethod
+    def _callback(self, **kwargs) -> models.CallbackDataResponse:
+        pass
+
+    def callback(self, callback_id: UUID):
+        return self._callback(
+            callback_id=callback_id,
+        )
+
     @abstractmethod
     def _digestion(self, **kwargs) -> models.DigestionDataResponse:
         pass
@@ -297,6 +306,25 @@ class FetchInterface(BaseFetchInterface):
             object_store_id=object_store_id,
         )
 
+    @abstractmethod
+    def _object_store_session_credentials(
+        self, **kwargs
+    ) -> models.ObjectStoreSessionCredentialsDataResponse:
+        pass
+
+    def object_store_session_credentials(self, object_store_id: UUID):
+        """
+        Fetches session credentials for an object store given its ID.
+
+        Args:
+            object_store_id: The ID of the object store to fetch.
+        Returns:
+            A data response for the object store session credentials.
+        """
+        return self._object_store_session_credentials(
+            object_store_id=object_store_id,
+        )
+
     @abstractmethod
     def _query(self, **kwargs) -> models.QueryDataResponse:
         pass
