@@ -8,6 +8,70 @@ from lqs.interface.base.list import ListInterface as BaseListInterface
 
 
 class ListInterface(BaseListInterface):
+    @abstractmethod
+    def _callback(self, **kwargs) -> models.CallbackListResponse:
+        pass
+
+    def callback(
+        self,
+        id: Optional[UUID] = None,
+        name: Optional[str] = None,
+        name_like: Optional[str] = None,
+        note_like: Optional[str] = None,
+        context_filter: Optional[str] = None,
+        parameter_schema_filter: Optional[str] = None,
+        include_count: Optional[bool] = True,
+        offset: Optional[int] = 0,
+        limit: Optional[int] = 100,
+        order: Optional[str] = "created_at",
+        sort: Optional[str] = "ASC",
+        created_by: Optional[UUID] = None,
+        updated_by: Optional[UUID] = None,
+        deleted_by: Optional[UUID] = None,
+        updated_by_null: Optional[bool] = None,
+        deleted_by_null: Optional[bool] = None,
+        updated_at_null: Optional[bool] = None,
+        deleted_at_null: Optional[bool] = None,
+        created_at_lte: Optional[datetime] = None,
+        updated_at_lte: Optional[datetime] = None,
+        deleted_at_lte: Optional[datetime] = None,
+        created_at_gte: Optional[datetime] = None,
+        updated_at_gte: Optional[datetime] = None,
+        deleted_at_gte: Optional[datetime] = None,
+    ):
+        """
+        Lists callbacks.
+        """
+        return self._callback(
+            id=id,
+            name=name,
+            name_like=name_like,
+            note_like=note_like,
+            context_filter=context_filter,
+            parameter_schema_filter=parameter_schema_filter,
+            include_count=include_count,
+            offset=offset,
+            limit=limit,
+            order=order,
+            sort=sort,
+            created_by=created_by,
+            updated_by=updated_by,
+            deleted_by=deleted_by,
+            updated_by_null=updated_by_null,
+            deleted_by_null=deleted_by_null,
+            updated_at_null=updated_at_null,
+            deleted_at_null=deleted_at_null,
+            created_at_lte=created_at_lte,
+            updated_at_lte=updated_at_lte,
+            deleted_at_lte=deleted_at_lte,
+            created_at_gte=created_at_gte,
+            updated_at_gte=updated_at_gte,
+            deleted_at_gte=deleted_at_gte,
+        )
+
+    def callbacks(self, **kwargs):
+        return self.callback(**kwargs)
+
     @abstractmethod
     def _digestion(self, **kwargs) -> models.DigestionListResponse:
         pass
@@ -26,6 +90,7 @@ class ListInterface(BaseListInterface):
         progress_gte: Optional[float] = None,
         progress_lte: Optional[float] = None,
         error_filter: Optional[str] = None,
+        error_payload_filter: Optional[str] = None,
         note_like: Optional[str] = None,
         context_filter: Optional[str] = None,
         workflow_context_filter: Optional[str] = None,
@@ -64,6 +129,7 @@ class ListInterface(BaseListInterface):
             progress_gte=progress_gte,
             progress_lte=progress_lte,
             error_filter=error_filter,
+            error_payload_filter=error_payload_filter,
             note_like=note_like,
             context_filter=context_filter,
             workflow_context_filter=workflow_context_filter,
@@ -390,6 +456,7 @@ class ListInterface(BaseListInterface):
         progress_gte: Optional[float] = None,
         progress_lte: Optional[float] = None,
         error_filter: Optional[str] = None,
+        error_payload_filter: Optional[str] = None,
         note_like: Optional[str] = None,
         context_filter: Optional[str] = None,
         include_count: Optional[bool] = True,
@@ -431,6 +498,7 @@ class ListInterface(BaseListInterface):
             progress_gte=progress_gte,
             progress_lte=progress_lte,
             error_filter=error_filter,
+            error_payload_filter=error_payload_filter,
             note_like=note_like,
             context_filter=context_filter,
             include_count=include_count,
@@ -803,6 +871,8 @@ class ListInterface(BaseListInterface):
     def object_store(
         self,
         id: Optional[UUID] = None,
+        name: Optional[str] = None,
+        name_like: Optional[str] = None,
         bucket_name: Optional[str] = None,
         bucket_name_like: Optional[str] = None,
         access_key_id: Optional[str] = None,
@@ -811,6 +881,8 @@ class ListInterface(BaseListInterface):
         note: Optional[str] = None,
         note_like: Optional[str] = None,
         disabled: Optional[bool] = None,
+        managed: Optional[bool] = None,
+        default: Optional[bool] = None,
         include_count: Optional[bool] = True,
         offset: Optional[int] = 0,
         limit: Optional[int] = 100,
@@ -835,6 +907,8 @@ class ListInterface(BaseListInterface):
         """
         return self._object_store(
             id=id,
+            name=name,
+            name_like=name_like,
             bucket_name=bucket_name,
             bucket_name_like=bucket_name_like,
             access_key_id=access_key_id,
@@ -843,6 +917,8 @@ class ListInterface(BaseListInterface):
             note=note,
             note_like=note_like,
             disabled=disabled,
+            managed=managed,
+            default=default,
             include_count=include_count,
             offset=offset,
             limit=limit,
@@ -1242,6 +1318,7 @@ class ListInterface(BaseListInterface):
         default: Optional[bool] = None,
         disabled: Optional[bool] = None,
         managed: Optional[bool] = None,
+        process_type: Optional[str] = None,
         context_schema_filter: Optional[str] = None,
         include_count: Optional[bool] = True,
         offset: Optional[int] = 0,
@@ -1272,6 +1349,7 @@ class ListInterface(BaseListInterface):
             default=default,
             disabled=disabled,
             managed=managed,
+            process_type=process_type,
             context_schema_filter=context_schema_filter,
             include_count=include_count,
             offset=offset,
