@@ -15,8 +15,10 @@ from lqs.interface.base.models.__common__ import (  # noqa: F401
     PatchOperation,
     JSONFilter,
     optional_field,
+    optional_deprecated_field,
     optional_field_alt,
     Int64,
+    SpecialDict,
 )
 
 
@@ -47,17 +49,17 @@ class TypeEncoding(str, Enum):
 
 class LockModel(BaseModel):
     locked: bool = Field(
-        False,
+        ...,
         description="Whether the process is locked (i.e. cannot be modified).",
     )
     locked_by: Optional[UUID] = Field(
-        None, description="The ID of the user who locked the resource."
+        ..., description="The ID of the user who locked the resource."
     )
     locked_at: Optional[datetime] = Field(
-        None, description="The time at which the resource was locked."
+        ..., description="The time at which the resource was locked."
     )
     lock_token: Optional[str] = Field(
-        None, description="The token used to lock the resource."
+        ..., description="The token used to lock the resource."
     )
 
 
@@ -79,24 +81,53 @@ class ProcessModel(CommonModel[T], LockModel):
         None,
         description="The context to be passed to the workflow during state transitions.",
     )
-    state: ProcessState = Field(
-        ProcessState.ready, description="The current state of the process."
-    )
+    state: ProcessState = Field(..., description="The current state of the process.")
 
     # These fields should not be modified by a user and only by the process.
     progress: Optional[float] = Field(
         None,
         description="The progress of the process for the current state (a float in [0,1]).",
     )
+    previous_state: Optional[ProcessState] = Field(
+        None,
+        description="The previous state of the process.",
+    )
     transitioned_at: Optional[datetime] = Field(
         None,
         description="The time at which the process transitioned to the current state.",
     )
     error: Optional[dict] = Field(
         None,
-        description="The JSON payload of an error that occurred during the process.",
+        description="The name of the error that occurred during the process.",
+        deprecated="Use error_payload instead.",
     )
 
+    error_name: Optional[str] = Field(
+        None,
+        description="The name of the error that occurred during the process.",
+    )
+    error_message: Optional[str] = Field(
+        None,
+        description="The message of the error that occurred during the process.",
+    )
+    error_payload: Optional[dict] = Field(
+        None,
+        description="The payload of the error that occurred during the process.",
+    )
+
+
+process_required_fields = [
+    "workflow_id",
+    "workflow_context",
+    "progress",
+    "previous_state",
+    "transitioned_at",
+    "error",
+    "error_name",
+    "error_message",
+    "error_payload",
+]
+
 
 class ProcessCreateRequest(LockCreateRequest):
     workflow_id: Optional[UUID] = None
@@ -109,4 +140,7 @@ class ProcessUpdateRequest(LockUpdateRequest):
     workflow_context: Optional[dict] = optional_field
     state: ProcessState = optional_field
     progress: Optional[float] = optional_field
-    error: Optional[dict] = optional_field
+    error_name: Optional[str] = optional_field
+    error_message: Optional[str] = optional_field
+    error_payload: Optional[dict] = optional_field
+    error: Optional[dict] = optional_deprecated_field
