@@ -1,4 +1,5 @@
 from lqs.interface.core.models.api_key import *
+from lqs.interface.core.models.callback import *
 from lqs.interface.core.models.digestion import *
 from lqs.interface.core.models.digestion_part import *
 from lqs.interface.core.models.digestion_topic import *
@@ -47,11 +48,13 @@ from lqs.interface.core.models.tag import *
 from lqs.interface.core.models.user import *
 from lqs.interface.core.models.workflow import *
 
+from lqs.interface.core.models.jsonl import *
 from lqs.interface.core.models.__common__ import *
 
 
 class Resources:
     APIKey = APIKey
+    Callback = Callback
     Digestion = Digestion
     DigestionPart = DigestionPart
     DigestionTopic = DigestionTopic
