@@ -1,7 +1,7 @@
 from typing import List, Optional
 from datetime import datetime
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field, ConfigDict
 
 from lqs.interface.base.models.__common__ import (
     ResourceModel,
@@ -12,12 +12,34 @@ from lqs.interface.base.models.__common__ import (
 class Object(ResourceModel["Object"]):
     _repr_fields = ("key",)
 
-    key: str
-    etag: Optional[str]
-    size: Optional[int]
-    last_modified: Optional[datetime]
-    presigned_url: Optional[str]
-    upload_state: UploadState
+    key: str = Field(
+        ...,
+        description="The key of the object (i.e., the path within the object store).",
+    )
+    etag: Optional[str] = Field(
+        None, description="The ETag of the object, used for integrity checks."
+    )
+    size: Optional[int] = Field(None, description="The size of the object in bytes.")
+    last_modified: Optional[datetime] = Field(
+        None, description="The last modified timestamp of the object."
+    )
+    presigned_url: Optional[str] = Field(
+        None, description="The presigned URL for fetching the object data."
+    )
+    upload_state: UploadState = Field(
+        ..., description="The upload state of the object."
+    )
+
+    model_config = ConfigDict(
+        json_schema_extra=lambda x: x["required"].extend(
+            [
+                "etag",
+                "size",
+                "last_modified",
+                "presigned_url",
+            ]
+        )
+    )
 
 
 class ObjectDataResponse(BaseModel):
