@@ -58,3 +58,7 @@ class JobType(str, Enum):
     copy = "copy"
     post_copy = "post_copy"
     failed_copy = "failed_copy"
+
+    rectify = "rectify"
+    post_rectify = "post_rectify"
+    failed_rectify = "failed_rectify"
