@@ -73,7 +73,7 @@ class RoleCreateRequest(BaseModel):
 
 class RoleUpdateRequest(BaseModel):
     name: str = optional_field
-    policy: dict = optional_field
+    policy: Policy = optional_field
     note: Optional[str] = optional_field
     disabled: bool = optional_field
     default: bool = optional_field
