@@ -28,7 +28,9 @@ primitive_types = {
 }
 
 
-def handle_initialization(ark_json_schema, field, current_package)->Tuple[List[str],Any]:
+def handle_initialization(
+    ark_json_schema, field, current_package
+) -> Tuple[List[str], Any]:
     if "attributes" in field:
         if (
             "constant" in field["attributes"]
@@ -60,8 +62,8 @@ def handle_initialization(ark_json_schema, field, current_package)->Tuple[List[s
     if field["type"] == "dictionary":
         return [], "{}"
     if field["type"] == "enum":
-        object_namespace:str
-        name:str
+        object_namespace: str
+        name: str
         object_namespace, name = field["object_type"].rsplit("::", 1)
         enum = next(
             enum
@@ -85,8 +87,8 @@ def handle_initialization(ark_json_schema, field, current_package)->Tuple[List[s
             return [object_namespace], f"{object_namespace}.{name}({value})"
 
     if field["type"] == "object":
-        object_namespace:str
-        name:str
+        object_namespace: str
+        name: str
         object_namespace, name = field["object_type"].rsplit("::", 1)
         if object_namespace == current_package:
             return [], f"{name}()"
@@ -95,9 +97,9 @@ def handle_initialization(ark_json_schema, field, current_package)->Tuple[List[s
     if field["type"] == "variant":
         imports = []
         init = None
-        for index,variant_type in field["variant_types"]:
+        for index, variant_type in field["variant_types"]:
             object_namespace, name = variant_type.rsplit("::", 1)
-        
+
             if object_namespace == current_package and init is None:
                 init = f"{name}()"
             else:
@@ -168,7 +170,7 @@ def get_read_fn(ark_json_schema, field, current_package):
             field=field["ctr_value_type"],
             current_package=current_package,
         )
-        assert read_key_fn 
+        assert read_key_fn
         assert read_value_fn
         return f"lambda *args, **kwargs: read_dictionary(read_key={read_key_fn}, read_value={read_value_fn}, stream=kwargs['stream'], TRIM_SIZE=kwargs['TRIM_SIZE'])"
     if field["type"] == "enum":
@@ -186,11 +188,11 @@ def get_read_fn(ark_json_schema, field, current_package):
         return f"read_{field['type']}"
 
     if field["type"] == "variant":
-        index:int
+        index: int
         variant_type: str
         types_dict = {}
         types_dict_str = "{"
-        for index,variant_type in field["variant_types"]:
+        for index, variant_type in field["variant_types"]:
             object_namespace, name = variant_type.rsplit("::", 1)
             if object_namespace == current_package:
                 object_name = f"{name}"
@@ -213,9 +215,10 @@ def handle_arbitrary_name(value):
     If the passed string is a python  keyword, "escape"  it by adding  `_lqs_` prefix
     """
     if keyword.iskeyword(value):
-        return "_lqs_"+value
+        return "_lqs_" + value
     return value
 
+
 def convert_enum(enum_schema):
     enum_class = enum_schema["enum_class"]
     assert enum_class in {
@@ -228,20 +231,27 @@ def convert_enum(enum_schema):
         "uint32",
         "uint64",
     }, f"enum_class has to be one of 'int8' / 'int16' / 'int32' / 'int64' / 'uint8' / 'uint16' / 'uint32' / 'uint64' but was {enum_class}"
-    name, object_namespace = handle_arbitrary_name(enum_schema["name"]), enum_schema["object_namespace"]
+    name, object_namespace = (
+        handle_arbitrary_name(enum_schema["name"]),
+        enum_schema["object_namespace"],
+    )
     enum_type = enum_schema["enum_type"]
     if enum_type == "bitmask":
         enum_class_def = (
             f"""from enum import IntFlag\nclass {enum_schema['name']}(IntFlag):"""
         )
         for enum_value_name, enum_value in enum_schema["values"].items():
-            enum_class_def += f"""\n\t{handle_arbitrary_name(enum_value_name)} = {enum_value}"""
+            enum_class_def += (
+                f"""\n\t{handle_arbitrary_name(enum_value_name)} = {enum_value}"""
+            )
     elif enum_type == "value":
         enum_class_def = (
             f"""from enum import IntEnum\nclass {enum_schema['name']}(IntEnum):"""
         )
         for enum_value_name, enum_value in enum_schema["values"].items():
-            enum_class_def += f"""\n\t{handle_arbitrary_name(enum_value_name)} = {enum_value}"""
+            enum_class_def += (
+                f"""\n\t{handle_arbitrary_name(enum_value_name)} = {enum_value}"""
+            )
     else:
         raise Exception("Not implemented yet", enum_type)
     return object_namespace, name, enum_class_def
@@ -266,7 +276,9 @@ def converter(ark_json_schema, type_identifier, recursive_call=False):
         and schema["attributes"]["final"] is True
     )
     name = schema["name"]
-    assert not keyword.iskeyword(name), f"Cannot have a reserved keyword as the schema name: {name}"
+    assert not keyword.iskeyword(
+        name
+    ), f"Cannot have a reserved keyword as the schema name: {name}"
     class_def = f"""class {name}:\n\tdef __init__(self):\n"""
     for field in schema["fields"]:
         field["name"] = handle_arbitrary_name(field["name"])
@@ -279,7 +291,7 @@ def converter(ark_json_schema, type_identifier, recursive_call=False):
             imports.update(new_import)
         if field_initialization is not None:
             class_def += f"\t\tself.{field['name']} = {field_initialization}\n"
-    if not schema['fields']:
+    if not schema["fields"]:
         class_def += f"\t\tpass\n"
     for group in schema["groups"]:
         for field in group["fields"]:
@@ -313,10 +325,10 @@ def converter(ark_json_schema, type_identifier, recursive_call=False):
             and field["attributes"]["removed"] is True
         ):
             read_statement = get_read_statement(
-                    ark_json_schema=ark_json_schema,
-                    field=field,
-                    current_package=object_namespace,
-                )
+                ark_json_schema=ark_json_schema,
+                field=field,
+                current_package=object_namespace,
+            )
             class_def += f"\t\t{read_statement}\n"
             continue
         # for optional fields we read a bool and if its true we read the value
@@ -325,7 +337,17 @@ def converter(ark_json_schema, type_identifier, recursive_call=False):
             and "optional" in field["attributes"]
             and field["attributes"]["optional"] is True
         ):
-            class_def += f"\t\tif read_bool(stream, TRIM_SIZE=TRIM_SIZE):\n\t\t\tself.{field['name']} = read_{field['type']}(stream, TRIM_SIZE=TRIM_SIZE)\n"
+            class_def += f"\t\tif read_bool(stream, TRIM_SIZE=TRIM_SIZE):\n"
+            field_type = field["type"]
+            if field_type == "object":
+                read_statement = get_read_statement(
+                    ark_json_schema=ark_json_schema,
+                    field=field,
+                    current_package=object_namespace,
+                )
+                class_def += f"\t\t\tself.{field['name']} = {read_statement}\n"
+            else:
+                class_def += f"\t\t\tself.{field['name']} = read_{field_type}(stream, TRIM_SIZE=TRIM_SIZE)\n"
             continue
 
         read_statement = get_read_statement(
