@@ -31,8 +31,20 @@ class CDRWrapper:
             types_dict = get_types_from_msg(text=type_data, name=type_name)
             self.type_store.register(typs=types_dict)
 
-        res = self.type_store.deserialize_cdr(
-            rawdata=message_bytes,
-            typename=type_name,
-        )
+        try:
+            res = self.type_store.deserialize_cdr(
+                rawdata=message_bytes,
+                typename=type_name,
+            )
+        except KeyError as e:
+            # it's possible that the type name isn't formatted as expected
+            # count how many '/' is in the type name
+            if type_name.count("/") == 1:
+                corrected_type_name = type_name.replace("/", "/msg/", 1)
+                res = self.type_store.deserialize_cdr(
+                    rawdata=message_bytes,
+                    typename=corrected_type_name,
+                )
+            else:
+                raise e
         return orjson.loads(orjson.dumps(res, default=NumpyEncoder().default))
